<?php

namespace App\Http\Controllers\Auth;

use App\User;
use App\Sex;
use App\Career;
use DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;
use Illuminate\Foundation\Auth\RegistersUsers;

class RegisterController extends Controller
{

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = '/thanks';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }


    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {

        $now = new \DateTime();
        $nowV = $now->format('Y-m-d');

        return Validator::make($data, [
            'nombre' => 'required|regex:/^[\pL\s\-]+$/u|max:50',
            'apellido' => 'required|regex:/^[\pL\s\-]+$/u|max:50',
            'email' => 'required|string|email|max:100|unique:users',
            'password' => 'required|string|min:6|max:50|confirmed',
            'id_sexo' => 'required',
            'fecha_nacimiento' => 'required|after_or_equal:1910-01-01|before:'.$nowV,
            'id_carrera' => 'required',
            'numero_tel' => 'required|digits:10',
            'terminos' => 'required',

        ]);
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param  array  $data
     * @return \App\User
     */
    protected function create(array $data)
    {
        $data['confirmation_code'] = str_random(25);
        $user = User::create([
            'nombre' => $data['nombre'],
            'apellido' => $data['apellido'],
            'email' => $data['email'],
            'password' => bcrypt($data['password']),
            'id_rol' => 0,
            'id_sexo' => $data['id_sexo'],
            'id_pais' => 1,
            'id_estado' => 1,
            'fecha_nacimiento' => $data['fecha_nacimiento'],
            'id_carrera' => $data['id_carrera'],
            'numero_tel' => $data['numero_tel'],
            'confirmation_code' => $data['confirmation_code']
        ]);

        // Send confirmation code
        Mail::send('emails.confirmation_code', $data, function ($message) use ($data){
           $message->to($data['email'], $data['nombre'] . " " . $data['apellido'])->subject('Por favor confirma tu correo');
        });
        

        return $user;
    }

    public function verify($code, $email)
    {
         $user = User::where('confirmation_code', $code)->first();

         if (! $user)
         {
             return redirect('/');
         }

         $user->confirmed = true;
         $user->confirmation_code = 'c';
         $user->save();
         return redirect('/thanks')->with('email', $email);
    }
}
