<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Product;

class CartController extends Controller
{
    // Funciones para carrito de compras.

    public function __construct(){

      if (!\Session::has('cart')) \Session::put('cart', array());

    }

    // Show Cart
    public function show(){

      $cart = \Session::get('cart');
      $total = $this->total();
      return view('products.cart', compact('cart', 'total'));

    }

    // Add item
    public function add(Product $product){

      $cart = \Session::get('cart');
      $product->cantidad = 1;
      $cart[$product->id] = $product;
      \Session::put('cart', $cart);

      return redirect()->route('cart-show');

    }

    // Delete item
    public function delete(Product $product){

      $cart = \Session::get('cart');
      unset($cart[$product->id]);
      \Session::put('cart', $cart);

      return redirect()->route('cart-show');

    }

    // Update item
    public function update(Product $product, $quantity){

      $cart = \Session::get('cart');
      $cart[$product->id]->cantidad = $quantity;
      \Session::put('cart', $cart);

      return redirect()->route('cart-show');

    }

    // Trash cart
    public function trash(){

      \Session::forget('cart');
      return redirect()->route('cart-show');

    }

    // Total
    private function total(){

        $cart = \Session::get('cart');
        $total = 0;

        foreach ($cart as $item) {
          $total += $item->precio * $item->cantidad;
        }

        return $total;

    }

    //Detalle del pedido
    public function orderDetail(){

      if (count(\Session::get('cart')) <= 0) return redirect('/');
      $cart = \Session::get('cart');
      $total = $this->total();

      return view('products.order-detail', compact('cart', 'total'));

    }

}
